Learn R Programming

SciencesPo (version 0.05.21)

SciencesPo-package: Tools for analyzing political behaviour data

Description

SciencesPo is a facility package for the political science crowd. It provides well-founded functions for analyzing random and nonrandom data. Future updates will focus on innovative techniques published in relevant journals in the field of political science.

Arguments

encoding

UTF-8

Details

ll{ Package: SciencesPo Type: Package Version: 0.05.21 Date: 2014-05-21 License: LGPL (>= 2.0, < 3) }

References

Marcelino, Daniel (2010). Sobre dinheiro e eleições: um estudo dos gastos de campanha para o Congresso Nacional em 2002 e 2006.

Marcelino, Daniel (2013). SciencesPo: A Tool Set for Analyzing Political Behaviour Data. Available at SSRN: http://dx.doi.org/10.2139/ssrn.2320547