Learn R Programming

SciencesPo (version 0.3.8.27)

montreal: Juvenile Crimes in Montreal

Description

Data set containing number of crimes committed by teenagers in Montreal in 2007. I have added spatial coordinates to allow for spatial analysis.

Usage

data(montreal)

Arguments

encoding

latin1

source

Report of the PVM--Montreal Police Service (2007).

References

http://danielmarcelino.com/SciencePo

Examples

Run this code
data(montreal)

Run the code above in your browser using DataLab