Learn R Programming

SciencesPo (version 0.3.8.27)

soundexES: Spanish Soundex Encoding

Description

SoundexES function returns a Census-like soundex code for a string given the hispanic sound system. This function was firstly outlined to work with the RecordLinkage package. Nonetheless, the soundex codes can be helpful in many other settings. See details bellow.

Usage

soundexES(term)

Arguments

term
is the vector with character strings.

Value

  • A character vector or matrix with the same dimensions as term.

encoding

latin1

References

Borg, Andreas and Murat Sariyar. (2012) RecordLinkage: Record Linkage in R, R package version 0.4-1, http://CRAN.R-project.org/package=RecordLinkage.

See Also

soundexBR, soundexFR .

Examples

Run this code
soundexES(x <- c('Alejandro Angel Tapias', 'Alejandro Tapias',
'Alejandro A. Tapias', 'Alexander Angel Tapias',
'Alexandre Angel Tapias'))

soundexES(y <- c('Beatriz Rivera', 'Carol Galais', 'Evita Perón', 
'Irene Martin') )

Run the code above in your browser using DataLab