Learn R Programming

SciencesPo (version 0.03.21)

SciencesPo-package: Tools for analyzing political behaviour data

Description

SciencesPo is a facility package for the political science crowd. It provides well-founded functions for analyzing random and nonrandom data. Future updates will focus on innovative techniques published in relevant journals of the field.

Arguments

encoding

UTF-8

Details

ll{ Package: SciencesPo Type: Package Version: 0.03.21 Date: 2014-03-21 License: LGPL (>= 2.0, < 3) }

References

Marcelino, Daniel (2010). Sobre dinheiro e eleições: um estudo dos gastos de campanha para o Congresso Nacional em 2002 e 2006.

Marcelino, Daniel (2013). SciencesPo: A Tool Set for Analyzing Political Behaviour Data. Available at SSRN: http://dx.doi.org/10.2139/ssrn.2320547

See Also

detail, fptp2av, dummy, psum, shift, soundexBR, beta.coef, rprob, get.ci

Examples

Run this code
# Loading some data 
data(montreal)

detail(montreal) 

anonymize(montreal)

rprob(nerlove63)

rstack(rprob(nerlove63))

lsq(4, 3, seed = 123)

get.ci(sample = 800, n = 1, mu = .29)

Run the code above in your browser using DataLab