Generate standardized beta coefficients from an adjusted model. Standardized coefficients refer to how many standard deviations a dependent variable will change per standard deviation increase in the predictor variable. See details.
Usage
beta.coef(md)
Arguments
md
is a linear object model.
Value
a numeric value of standardized beta coefficient.
Details
Standardized beta coefficients--also known as beta coefficients--are quantities estimated from unstandardized coefficients, which are partially adjusted by the quotient of the standard deviation of an independent variable, and the standard deviation of a dependent variable. Basically, beta coefficients report the relative importance of each independent variables. The standardization is typically done after running a multiple regression model, since it aids the researcher to identify which independent variables have the greater effect. Therefore, the standardization procedure is specially useful when variables are measured in different units.
References
Baguley, T. (2009) Standardized or simple effect size: What should be reported?. British Journal of Psychology,100(3), 603-617.
Dallal, J. Which Predictors Are More Important? http://www.jerrydallal.com/LHSP/importnt.htm
Gelman, A., & Hill, J. (2006) Data analysis using regression and multilevel/hierarchical models. Cambridge University Press.