SoundexFR function returns a Census-like soundex code for a string given the Francophone sound system. This function was firstly outlined to work with the RecordLinkage package. Nonetheless, the soundex codes can be helpful in many other settings. See details bellow.
Usage
soundexFR(term)
Arguments
term
is the vector with character strings.
Value
A character vector or matrix with the same dimensions as term.
encoding
latin1
References
Borg, Andreas and Murat Sariyar. (2012) RecordLinkage: Record Linkage in R, R package version 0.4-1, http://CRAN.R-project.org/package=RecordLinkage.